@@ -21,7 +21,7 @@ dirknn <- function(xnew, ina, x, k = 5, mesos = TRUE, parallel = FALSE, rann = F
 
   if ( rann ) {
     klen <- length(k)
-    di <- RANN::nn2( data = x, query = xnew, k = max(k) )$nn.idx
+    di <- Rnanoflann::nn( data = x, points = xnew, k = max(k) )$indices
     g <- matrix(nrow = nu, ncol = klen)
     m1 <- matrix(nrow = max(k), ncol = nu)
     for ( i in 1:nu )  m1[, i] <- ina[ di[i, ] ]
