@@ -31,7 +31,8 @@ vmf.reg <- function(y, x, con = TRUE, xnew = NULL, tol = 1e-06) {
     mu <- x %*% be
     ki <- sqrt( Rfast::rowsums(mu^2) )
     est <- mu / ki
-    fit <- sum( y * est )
+    #fit <- sum( y * est )
+	fit <- Rfast::XopY.sum(y, est) 
   } else {
     xnew <- model.matrix( ~., data.frame(xnew) )
     if ( !con ) xnew <- xnew[, -1]
